==> mktcenter-service-threetree-1.0-20251014.063910-31-sources.jar: com/bizvane/mktcenterservice/models/po/MktLearnCourseRecordPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.util.Date;

public class MktLearnCourseRecordPO {
    private Long mktLearnCourseRecordId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long mktLearnCourseId;

    private String memberCode;

    private Integer learnTotalSecond;

    private Integer state;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktLearnCourseRecordId() {
        return mktLearnCourseRecordId;
    }

    public void setMktLearnCourseRecordId(Long mktLearnCourseRecordId) {
        this.mktLearnCourseRecordId = mktLearnCourseRecordId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getMktLearnCourseId() {
        return mktLearnCourseId;
    }

    public void setMktLearnCourseId(Long mktLearnCourseId) {
        this.mktLearnCourseId = mktLearnCourseId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode == null ? null : memberCode.trim();
    }

    public Integer getLearnTotalSecond() {
        return learnTotalSecond;
    }

    public void setLearnTotalSecond(Integer learnTotalSecond) {
        this.learnTotalSecond = learnTotalSecond;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}

==> mktcenter-service-threetree-1.0-20251016.090209-34-sources.jar: com/bizvane/mktcenterservice/models/po/MktLearnCourseRecordPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.util.Date;

public class MktLearnCourseRecordPO {
    private Long mktLearnCourseRecordId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long mktLearnCourseId;

    private String memberCode;

    private Integer state;

    private Integer exchangeState;

    private Date exchangeTime;

    private Integer exchangeCostPoint;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktLearnCourseRecordId() {
        return mktLearnCourseRecordId;
    }

    public void setMktLearnCourseRecordId(Long mktLearnCourseRecordId) {
        this.mktLearnCourseRecordId = mktLearnCourseRecordId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getMktLearnCourseId() {
        return mktLearnCourseId;
    }

    public void setMktLearnCourseId(Long mktLearnCourseId) {
        this.mktLearnCourseId = mktLearnCourseId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode == null ? null : memberCode.trim();
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getExchangeState() {
        return exchangeState;
    }

    public void setExchangeState(Integer exchangeState) {
        this.exchangeState = exchangeState;
    }

    public Date getExchangeTime() {
        return exchangeTime;
    }

    public void setExchangeTime(Date exchangeTime) {
        this.exchangeTime = exchangeTime;
    }

    public Integer getExchangeCostPoint() {
        return exchangeCostPoint;
    }

    public void setExchangeCostPoint(Integer exchangeCostPoint) {
        this.exchangeCostPoint = exchangeCostPoint;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}
